==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-galego.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Enviar");
define("_URL","URL");
define("_PRINTER","Versin para imprimir");
define("_FRIEND","Enviar a un amigo");
define("_YOURNAME","O seu nome");
define("_OK","Aceptar");
define("_RELATED","Enlaces relacionados");
define("_MOREABOUT","Mis acerca de");
define("_NEWSBY","Noticias de");
define("_MOSTREAD","Noticia mis lda sobre");
define("_READMORE","Ler mis...");
define("_BYTESMORE","bytes mis");
define("_COMMENTSQ","comentarios?");
define("_COMMENT","comentario");
define("_CONFIGURE","Configurar");
define("_LOGINCREATE","Entrar/Crear Conta");
define("_THRESHOLD","Puntos");
define("_NOCOMMENTS","Sen comentarios");
define("_NESTED","Aniados");
define("_FLAT","Plano");
define("_THREAD","Fo");
define("_OLDEST","Antigos Primeiro");
define("_NEWEST","Novos Primeiro");
define("_HIGHEST","Maior Puntuacin Primeiro");
define("_COMMENTSWARNING","Os comentarios son propiedade de quen os enviou. Non somos responsables do seu contido.");
define("_SCORE","Puntuacin");
define("_USERINFO","Informacin do Usuario");
define("_READREST","Le-lo resto do comentario...");
define("_REPLY","Responder a isto");
define("_REPLYMAIN","Enviar Comentario");
define("_NOSUBJECT","Sen Asunto");
define("_NOANONCOMMENTS","Non se permiten comentarios Annimos, <a href=\"modules.php?name=Your_Account\">rexstrese</a> por favor");
define("_PARENT","Pai");
define("_ROOT","Raz");
define("_UCOMMENT","Comentario");
define("_ALLOWEDHTML","Permitir HTML:");
define("_POSTANON","Envo Annimo");
define("_EXTRANS","Extrans (html tags a texto)");
define("_HTMLFORMATED","Formateado HTML");
define("_PLAINTEXT","Texto Plano");
define("_ONN","en...");
define("_SUBJECT","Asunto");
define("_COMMENTREPLY","Enviar Comentario");
define("_COMREPLYPRE","Vista previa do Comentario");
define("_NOTRIGHT","Algo non funcionou  pasar unha variable  sa funcin. Esta mensaxe  para manter as cousas no seu sitio");
define("_SENDAMSG","Enviar unha mensaxe");
define("_YOUSENDSTORY","Vostede enviar a noticia");
define("_TOAFRIEND","a un amigo:");
define("_FYOURNAME","O seu nome:");
define("_FYOUREMAIL","O seu E-Mail:");
define("_FFRIENDNAME","Nome do seu amigo:");
define("_FFRIENDEMAIL","E-Mail do seu amigo:");
define("_INTERESTING","Artigo interesante en");
define("_HELLO","Hola");
define("_YOURFRIEND","O seu amigo");
define("_CONSIDERED","considerou interesante o seguinte artigo e quixo enviarllo.");
define("_FDATE","Fecha");
define("_FTOPIC","Tema");
define("_YOUCANREAD","Pode ler artigos interesantes en");
define("_FSTORY","Noticia");
define("_HASSENT","foi enviada a");
define("_THANKS","Gracias!");
define("_RECOMMEND","Recomendar este sitio a un amigo");
define("_PDATE","Fecha");
define("_PTOPIC","Tema");
define("_COMESFROM","Este artigo proven de");
define("_THEURL","A direccin desta noticia :");
define("_PREVIEW","Vista Previa");
define("_NEWUSER","Novo Usuario");
define("_OPTIONS","Opcins");
define("_REFRESH","Recargar");
define("_ADD","Engadir");
define("_NOCOMMENTSACT","Desculpe, os Comentarios non estn permitidos para este artigo.");
define("_ARTICLEPOLL","Enquisa do Artigo");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-galego.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Enviar");
define("_URL","URL");
define("_PRINTER","Versin para imprimir");
define("_FRIEND","Enviar a un amigo");
define("_YOURNAME","O seu nome");
define("_OK","Aceptar");
define("_RELATED","Enlaces relacionados");
define("_MOREABOUT","Mis acerca de");
define("_NEWSBY","Noticias de");
define("_MOSTREAD","Noticia mis lda sobre");
define("_READMORE","Ler mis...");
define("_BYTESMORE","bytes mis");
define("_COMMENTSQ","comentarios?");
define("_COMMENT","comentario");
define("_CONFIGURE","Configurar");
define("_LOGINCREATE","Entrar/Crear Conta");
define("_THRESHOLD","Puntos");
define("_NOCOMMENTS","Sen comentarios");
define("_NESTED","Aniados");
define("_FLAT","Plano");
define("_THREAD","Fo");
define("_OLDEST","Antigos Primeiro");
define("_NEWEST","Novos Primeiro");
define("_HIGHEST","Maior Puntuacin Primeiro");
define("_COMMENTSWARNING","Os comentarios son propiedade de quen os enviou. Non somos responsables do seu contido.");
define("_SCORE","Puntuacin");
define("_USERINFO","Informacin do Usuario");
define("_READREST","Le-lo resto do comentario...");
define("_REPLY","Responder a isto");
define("_REPLYMAIN","Enviar Comentario");
define("_NOSUBJECT","Sen Asunto");
define("_NOANONCOMMENTS","Non se permiten comentarios Annimos, <a href=\"modules.php?name=Your_Account\">rexstrese</a> por favor");
define("_PARENT","Pai");
define("_ROOT","Raz");
define("_UCOMMENT","Comentario");
define("_ALLOWEDHTML","Permitir HTML:");
define("_POSTANON","Envo Annimo");
define("_EXTRANS","Extrans (html tags a texto)");
define("_HTMLFORMATED","Formateado HTML");
define("_PLAINTEXT","Texto Plano");
define("_ONN","en...");
define("_SUBJECT","Asunto");
define("_COMMENTREPLY","Enviar Comentario");
define("_COMREPLYPRE","Vista previa do Comentario");
define("_NOTRIGHT","Algo non funcionou  pasar unha variable  sa funcin. Esta mensaxe  para manter as cousas no seu sitio");
define("_SENDAMSG","Enviar unha mensaxe");
define("_YOUSENDSTORY","Vostede enviar a noticia");
define("_TOAFRIEND","a un amigo:");
define("_FYOURNAME","O seu nome:");
define("_FYOUREMAIL","O seu E-Mail:");
define("_FFRIENDNAME","Nome do seu amigo:");
define("_FFRIENDEMAIL","E-Mail do seu amigo:");
define("_INTERESTING","Artigo interesante en");
define("_HELLO","Hola");
define("_YOURFRIEND","O seu amigo");
define("_CONSIDERED","considerou interesante o seguinte artigo e quixo enviarllo.");
define("_FDATE","Fecha");
define("_FTOPIC","Tema");
define("_YOUCANREAD","Pode ler artigos interesantes en");
define("_FSTORY","Noticia");
define("_HASSENT","foi enviada a");
define("_THANKS","Gracias!");
define("_RECOMMEND","Recomendar este sitio a un amigo");
define("_PDATE","Fecha");
define("_PTOPIC","Tema");
define("_COMESFROM","Este artigo proven de");
define("_THEURL","A direccin desta noticia :");
define("_PREVIEW","Vista Previa");
define("_NEWUSER","Novo Usuario");
define("_OPTIONS","Opcins");
define("_REFRESH","Recargar");
define("_ADD","Engadir");
define("_NOCOMMENTSACT","Desculpe, os Comentarios non estn permitidos para este artigo.");
define("_ARTICLEPOLL","Enquisa do Artigo");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
